# pattools
Toolkit for neuro-imaging data manipulation and automation.

A collection of handy-dandy tools that Pat uses for neuro-imaging in python.

## pacs
Used to find and get imaging and report data from the PACS system

## timelines
Used for building longitudinal data sets

## resources
Quick access to useful resources

## ants, fsl
Thin wrappers for quick access to underlying calls to ANTS and FSL. You'll need to have those tools installed if you want to use them (or make calls that use that code), otherwise we'll complain.
